"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlindsCmdPlatform = void 0;
/* Copyright(C) 2017-2020, HJD (https://github.com/hjdhjd). All rights reserved.
 *
 * blindsCmd-platform.ts: homebridge-blinds-cmd platform class.
 */
const blindsCmd_blind_1 = require("./blindsCmd-blind");
const util_1 = __importDefault(require("util"));
class BlindsCmdPlatform {
    constructor(log, config, api) {
        this.accessories = [];
        this.blinds = [];
        this.debugMode = false;
        this.api = api;
        // Force this to DoorbirdConfig.
        this.config = {
            blinds: config.blinds
        };
        this.log = log;
        // We can't start without being configured.
        if (!config) {
            return;
        }
        // We need a Doorbird configured to do anything.
        if (!config.blinds) {
            this.log("No blinds have been configured.");
            return;
        }
        // Capture configuration parameters.
        if (config.debug) {
            this.debugMode = config.debug === true;
            this.debug("Debug logging on. Expect a lot of data.");
        }
        // Avoid a prospective race condition by waiting to configure our blinds until Homebridge is done
        // loading all the cached accessories it knows about, and calling configureAccessory() on each.
        api.on("didFinishLaunching" /* DID_FINISH_LAUNCHING */, this.configureBlinds.bind(this));
    }
    // This gets called when homebridge restores cached accessories at startup. We
    // intentionally avoid doing anything significant here, and save all that logic
    // for device discovery.
    configureAccessory(accessory) {
        // Add this to the accessory array so we can track it.
        this.accessories.push(accessory);
    }
    // Configure our blinds.
    configureBlinds() {
        // Loop through each configured blind and instantiate it.
        for (const blindsConfig of this.config.blinds) {
            // No name or up or down commands defined, we're done.
            if (!blindsConfig.up || !blindsConfig.down || !blindsConfig.name) {
                this.log("Name, up, and down commands are required configuration parameters.");
                continue;
            }
            this.blinds.push(new blindsCmd_blind_1.Blind(this, blindsConfig));
        }
    }
    // Utility for debug logging.
    debug(message, ...parameters) {
        if (this.debugMode) {
            this.log(util_1.default.format(message, ...parameters));
        }
    }
}
exports.BlindsCmdPlatform = BlindsCmdPlatform;
//# sourceMappingURL=blindsCmd-platform.js.map